@@ -3,6 +3,7 @@ import string
 from datetime import datetime, timezone
 from typing import List, Optional, Union
 
+from ._lamin_communicate import lamin_user_name, lamin_user_settings
 from ._meta_store import MetaContainer
 from ._notebook import Notebook
 
@@ -40,4 +41,13 @@ def initialize_metadata(
     if parent is not None:
         meta.parent = parent
 
+    user_handle, user_id = lamin_user_settings()
+    if user_handle is not None and user_id is not None:
+        meta.user_handle = user_handle
+        meta.user_id = user_id
+
+        user_name = lamin_user_name(user_id)
+        if user_name is not None:
+            meta.user_name = user_name
+
     return meta
